# ListWellKnownIssuerInfo

List of well known issuer information
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**well_known_info** | [**list[WellKnownIssuerInfo]**](WellKnownIssuerInfo.md) | List of well known issuer info | [optional] 
**limit** | **int** | Limit of issuers in the response | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


